@@ -1,18 +1,17 @@
-import sys
 import os
 import argparse
 import subprocess
 
-import markdown
-from jinja2 import Environment, FileSystemLoader
 
-from server import Server
-from path import Directory, ProjectDirectory
-from generator import Site
-import echo
+from .server import Server
+from .path import Directory, ProjectDirectory
+from .generator import Site
+from . import echo
+from . import event
+from .plugins import sitemap, feed
 
 
-__version__ = "0.0.13"
+__version__ = "0.1"
 
 
 def console():
@@ -65,6 +64,7 @@ def console():
 
     if args.command == 'compile':
         echo.out("compiling directory {} to {}...", project_dir.input_dir, output_dir)
+
         s = Site(project_dir, output_dir)
         s.output()
 
@@ -102,7 +102,3 @@ def console():
     echo.out("...done")
     return 0
 
-
-if __name__ == u'__main__':
-    sys.exit(console())
-
